==> hipsolver-5.6.1-1-x86_64.pkg.tar.zst: opt/rocm/hipsolver/include/internal/hipsolver-version.h <==
/*
    Copyright (c) 2022 Advanced Micro Devices, Inc. All rights reserved.
*/

#ifndef ROCM_WRAPPER_INTERNAL_HIPSOLVER_VERSION_H
#define ROCM_WRAPPER_INTERNAL_HIPSOLVER_VERSION_H

#if defined(ROCM_NO_WRAPPER_HEADER_WARNING) || defined(ROCM_WRAPPER_GAVE_WARNING)
/* include file */
#include "../../../include/hipsolver/internal/hipsolver-version.h"
#else
#ifndef ROCM_HEADER_WRAPPER_WERROR
#define ROCM_HEADER_WRAPPER_WERROR 0
#endif
#if ROCM_HEADER_WRAPPER_WERROR  /* ROCM_HEADER_WRAPPER_WERROR 1 */
#error "This file is deprecated. Use the header file from /opt/rocm/include/hipsolver/internal/hipsolver-version.h by using #include <hipsolver/internal/hipsolver-version.h>"
#else  /* ROCM_HEADER_WRAPPER_WERROR 0 */
/* give warning */
#if defined(_MSC_VER)
#pragma message(": warning:This file is deprecated. Use the header file from /opt/rocm/include/hipsolver/internal/hipsolver-version.h by using #include <hipsolver/internal/hipsolver-version.h>")
#elif defined(__GNUC__)
#warning "This file is deprecated. Use the header file from /opt/rocm/include/hipsolver/internal/hipsolver-version.h by using #include <hipsolver/internal/hipsolver-version.h>"
#endif
#endif  /* ROCM_HEADER_WRAPPER_WERROR */
/* include file */
#define ROCM_WRAPPER_GAVE_WARNING
#include "../../../include/hipsolver/internal/hipsolver-version.h"
#undef ROCM_WRAPPER_GAVE_WARNING
#endif /* defined(ROCM_NO_WRAPPER_HEADER_WARNING) || defined(ROCM_WRAPPER_GAVE_WARNING) */

#endif /* ROCM_WRAPPER_INTERNAL_HIPSOLVER_VERSION_H */

#if 0

/* The following is a copy of the original file for the benefit of build systems which grep for values
 * in this file rather than preprocess it. This is just for backward compatibility */

/* ************************************************************************
 * Copyright (C) 2020-2022 Advanced Micro Devices, Inc.
 * ************************************************************************ */

#ifndef HIPSOLVER_VERSION_H_
#define HIPSOLVER_VERSION_H_

/* the configured version and settings
 */
// clang-format off
#define hipsolverVersionMajor 1
#define hipsolverVersionMinor 8
#define hipsolverVersionPatch 0
#define hipsolverVersionTweak 
// clang-format on

#endif

#endif

==> hipsolver-5.7.1-1-x86_64.pkg.tar.zst: opt/rocm/hipsolver/include/internal/hipsolver-version.h <==
/*
    Copyright (c) 2022 Advanced Micro Devices, Inc. All rights reserved.
*/

#ifndef ROCM_WRAPPER_INTERNAL_HIPSOLVER_VERSION_H
#define ROCM_WRAPPER_INTERNAL_HIPSOLVER_VERSION_H

#if defined(ROCM_NO_WRAPPER_HEADER_WARNING) || defined(ROCM_WRAPPER_GAVE_WARNING)
/* include file */
#include "../../../include/hipsolver/internal/hipsolver-version.h"
#else
#ifndef ROCM_HEADER_WRAPPER_WERROR
#define ROCM_HEADER_WRAPPER_WERROR 0
#endif
#if ROCM_HEADER_WRAPPER_WERROR  /* ROCM_HEADER_WRAPPER_WERROR 1 */
#error "This file is deprecated. Use the header file from /opt/rocm/include/hipsolver/internal/hipsolver-version.h by using #include <hipsolver/internal/hipsolver-version.h>"
#else  /* ROCM_HEADER_WRAPPER_WERROR 0 */
/* give warning */
#if defined(_MSC_VER)
#pragma message(": warning:This file is deprecated. Use the header file from /opt/rocm/include/hipsolver/internal/hipsolver-version.h by using #include <hipsolver/internal/hipsolver-version.h>")
#elif defined(__GNUC__)
#warning "This file is deprecated. Use the header file from /opt/rocm/include/hipsolver/internal/hipsolver-version.h by using #include <hipsolver/internal/hipsolver-version.h>"
#endif
#endif  /* ROCM_HEADER_WRAPPER_WERROR */
/* include file */
#define ROCM_WRAPPER_GAVE_WARNING
#include "../../../include/hipsolver/internal/hipsolver-version.h"
#undef ROCM_WRAPPER_GAVE_WARNING
#endif /* defined(ROCM_NO_WRAPPER_HEADER_WARNING) || defined(ROCM_WRAPPER_GAVE_WARNING) */

#endif /* ROCM_WRAPPER_INTERNAL_HIPSOLVER_VERSION_H */

#if 0

/* The following is a copy of the original file for the benefit of build systems which grep for values
 * in this file rather than preprocess it. This is just for backward compatibility */

/* ************************************************************************
 * Copyright (C) 2020-2023 Advanced Micro Devices, Inc.
 * ************************************************************************ */

#ifndef HIPSOLVER_VERSION_H
#define HIPSOLVER_VERSION_H

/* the configured version and settings
 */
// clang-format off
#define hipsolverVersionMajor 1
#define hipsolverVersionMinor 8
#define hipsolverVersionPatch 2
#define hipsolverVersionTweak 
// clang-format on

#endif /* HIPSOLVER_VERSION_H */

#endif
